@@ -7,12 +7,13 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __EYES_H__
@@ -34,6 +35,7 @@ typedef struct
 	GtkWidget   *align;
 	GtkWidget   *hbox;
 	GtkWidget   **eyes;
+	gboolean     single_row;
 	guint        timeout_id;
 	gint 	    *pointer_last_x;
 	gint 	    *pointer_last_y;
